Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: ios/chrome/browser/ui/content_suggestions/cells/content_suggestions_button_item.h

Issue 2761753002: Cleanup ContentSuggestions cells (Closed)
Patch Set: Fix tests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/cells/content_suggestions_button_item.h
diff --git a/ios/chrome/browser/ui/content_suggestions/content_suggestions_text_item.h b/ios/chrome/browser/ui/content_suggestions/cells/content_suggestions_button_item.h
similarity index 62%
rename from ios/chrome/browser/ui/content_suggestions/content_suggestions_text_item.h
rename to ios/chrome/browser/ui/content_suggestions/cells/content_suggestions_button_item.h
index f2f8752a40cb6ded0b28233f459004e713812bc0..aa7b5720292456ac4359991bba22ea00af8fea54 100644
--- a/ios/chrome/browser/ui/content_suggestions/content_suggestions_text_item.h
+++ b/ios/chrome/browser/ui/content_suggestions/cells/content_suggestions_button_item.h
@@ -2,14 +2,14 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_TEXT_ITEM_H_
-#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_TEXT_ITEM_H_
+#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CELLS_CONTENT_SUGGESTIONS_BUTTON_ITEM_H_
+#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CELLS_CONTENT_SUGGESTIONS_BUTTON_ITEM_H_
#import "ios/chrome/browser/ui/collection_view/cells/collection_view_item.h"
#import "ios/third_party/material_components_ios/src/components/CollectionCells/src/MaterialCollectionCells.h"
-// Item for a suggestions item with a title and subtitle.
-@interface ContentSuggestionsTextItem : CollectionViewItem
+// Item for a suggestions item with a title button and subtitle.
+@interface ContentSuggestionsButtonItem : CollectionViewItem
// Init a suggestions item with a |title| and a |subtitle|. |type| is the type
// of the item.
@@ -20,12 +20,12 @@
@end
-// Corresponding cell for a suggestion item.
-@interface ContentSuggestionsTextCell : MDCCollectionViewCell
+// Corresponding cell for the item.
+@interface ContentSuggestionsButtonCell : MDCCollectionViewCell
@property(nonatomic, readonly, strong) UIButton* titleButton;
@property(nonatomic, readonly, strong) UILabel* detailTextLabel;
@end
-#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_TEXT_ITEM_H_
+#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CELLS_CONTENT_SUGGESTIONS_BUTTON_ITEM_H_

Powered by Google App Engine
This is Rietveld 408576698